@@ -2,8 +2,6 @@
 #define MAINWINDOW_H
 
 #include <QMainWindow>
-#include <QtDBus>
-
 
 #include "branchpropeditor.h"
 #include "extrainfodialog.h"
@@ -76,7 +74,7 @@ private:
     void setupRecentMapsMenu();
     void setupMacros();
     void setupToolbars();
-    int currentView() const;
+    VymView* currentView() const;
 public:	
     MapEditor* currentMapEditor() const;
     VymModel* currentModel() const;
@@ -156,13 +154,14 @@ private slots:
     void getBugzillaData();
     void getBugzillaDataSubtree();
     void editFATE2URL();
-    void openVymLinks(const QStringList &);
+    void openVymLinks(const QStringList &, bool background=false);
     void editVymLink();
     void editOpenMultipleVymLinks();
 public slots:
     void editHeading();
     void editHeadingFinished(VymModel *m);
-    void editOpenVymLink();
+    void editOpenVymLink(bool background=false);
+    void editOpenVymLinkBackground();
 private slots:
     void editDeleteVymLink();
     void editToggleHideExport();
@@ -257,6 +256,7 @@ public:
 
 public slots:
     void settingsAutosaveTime();
+    void settingsTaskShowParentsLevel();
     void settingsAutoLayoutToggle();
     void settingsWriteBackupFileToggle();
     void settingsToggleAnimation();
@@ -293,11 +293,14 @@ public slots:
 private slots:
     void windowNextEditor();
     void windowPreviousEditor();
+    void nextSlide();
+    void previousSlide();
 
     void standardFlagChanged();
 
     void testFunction1();
     void testFunction2();
+    void toggleWinter();
     void toggleHideExport();
     void testCommand();
 
@@ -389,6 +392,7 @@ private:
     QAction* actionGetBugzillaDataSubtree;
     QAction* actionFATE2URL;
     QAction *actionOpenVymLink;
+    QAction *actionOpenVymLinkBackground;
     QAction *actionOpenMultipleVymLinks;
     QAction *actionEditVymLink;
     QAction *actionDeleteVymLink;
@@ -461,6 +465,8 @@ private:
 
     QAction *actionToggleHideMode;
 
+    QAction *actionToggleWinter;
+
     QActionGroup *actionGroupFormatFrameTypes;
 
     QActionGroup *actionGroupFormatLinkStyles;
@@ -489,6 +495,7 @@ private:
     QAction* actionSettingsUseHideExport;
     QAction* actionSettingsAutosaveToggle;
     QAction* actionSettingsAutosaveTime;
+    QAction* actionSettingsTaskShowParentsLevel;
     QAction* actionSettingsAutoLayoutToggle;
     QAction* actionSettingsWriteBackupFile;
     QAction* actionSettingsUseAnimation;
