@@ -182,12 +182,12 @@ bool OrnamentedObj::getFrameIncludeChildren()
     return frame->getFrameIncludeChildren ();
 }
 
-void OrnamentedObj::positionContents()	//FIXME-3 called multiple times for each object after moving an image with mouse
+void OrnamentedObj::positionContents()	//FIXME-2 called multiple times for each object after moving an image with mouse
 {
     //positionContents FIXME-2 need to consider frame in calcBBox and positionContents
     double x=absPos.x();
     double y=absPos.y();
-    double dp=frame->getPadding();
+    double dp=frame->getPadding() + frame->getBorderWidth();
     double dp2=dp/2;
     double ox=leftPad + dp;
     double oy=topPad + dp;
@@ -246,10 +246,12 @@ void OrnamentedObj::positionContents()	//FIXME-3 called multiple times for each
 
 void OrnamentedObj::move (double x, double y)
 {
+    // FIXME-0 unnecessary calls to positionContents, ...
+    //FIXME-8 
+    if (debug) qDebug()<<"     OO::move and posContents; updateLinkGeo; requestRepos";
     MapObj::move (x,y);
     positionContents();
     updateLinkGeometry();
-    requestReposition();
 }
 
 void OrnamentedObj::move (QPointF p)
@@ -259,7 +261,6 @@ void OrnamentedObj::move (QPointF p)
 
 void OrnamentedObj::moveBy (double x, double y)
 {
-
     MapObj::moveBy (x,y);
     frame->moveBy (x,y);
     systemFlags->moveBy (x,y);
